summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKarl Mikaelsson <derfian@cendio.se>2017-10-17 12:27:21 +0200
committerKarl Mikaelsson <derfian@cendio.se>2017-10-17 12:29:41 +0200
commit27e447555ed86d5a1e09440e8b5ed1ba4cd938d6 (patch)
tree0c3a71948a3b1bf204f6d3a6b157368a6815df77
parent3bb69ac4b83076e15d942f0d73fecfb49776e82c (diff)
downloadrdesktop-27e447555ed86d5a1e09440e8b5ed1ba4cd938d6.zip
Rename SEC_TAG_CLI_ constants to match specification
-rw-r--r--constants.h8
-rw-r--r--secure.c13
2 files changed, 11 insertions, 10 deletions
diff --git a/constants.h b/constants.h
index 85d2e0d..a266de3 100644
--- a/constants.h
+++ b/constants.h
@@ -152,10 +152,10 @@ enum MCS_PDU_TYPE
#define SEC_TAG_SRV_CRYPT 0x0c02
#define SEC_TAG_SRV_CHANNELS 0x0c03
-#define SEC_TAG_CLI_INFO 0xc001
-#define SEC_TAG_CLI_CRYPT 0xc002
-#define SEC_TAG_CLI_CHANNELS 0xc003
-#define SEC_TAG_CLI_CLUSTER 0xc004
+#define CS_CORE 0xc001
+#define CS_SECURITY 0xc002
+#define CS_NET 0xc003
+#define CS_CLUSTER 0xc004
#define SEC_TAG_PUBKEY 0x0006
#define SEC_TAG_KEYSIG 0x0008
diff --git a/secure.c b/secure.c
index bacb235..4f31ffe 100644
--- a/secure.c
+++ b/secure.c
@@ -420,8 +420,8 @@ sec_out_mcs_connect_initial_pdu(STREAM s, uint32 selected_protocol)
out_uint32_le(s, 0x61637544); /* OEM ID: "Duca", as in Ducati. */
out_uint16_be(s, ((length - 14) | 0x8000)); /* remaining length */
- /* Client information */
- out_uint16_le(s, SEC_TAG_CLI_INFO); /* type */
+ /* Client information (TS_UD_CS_CORE) */
+ out_uint16_le(s, CS_CORE); /* type */
out_uint16_le(s, 216); /* length */
out_uint32_le(s, rdpversion); /* version */
out_uint16_le(s, g_width); /* desktopWidth */
@@ -451,7 +451,7 @@ sec_out_mcs_connect_initial_pdu(STREAM s, uint32 selected_protocol)
/* Write a Client Cluster Data (TS_UD_CS_CLUSTER) */
uint32 cluster_flags = 0;
- out_uint16_le(s, SEC_TAG_CLI_CLUSTER); /* header.type */
+ out_uint16_le(s, CS_CLUSTER); /* header.type */
out_uint16_le(s, 12); /* length */
cluster_flags |= SEC_CC_REDIRECTION_SUPPORTED;
@@ -463,16 +463,17 @@ sec_out_mcs_connect_initial_pdu(STREAM s, uint32 selected_protocol)
out_uint32_le(s, cluster_flags);
out_uint32(s, g_redirect_session_id);
- /* Client encryption settings */
- out_uint16_le(s, SEC_TAG_CLI_CRYPT); /* type */
+ /* Client encryption settings (TS_UD_CS_SEC) */
+ out_uint16_le(s, CS_SECURITY); /* type */
out_uint16_le(s, 12); /* length */
out_uint32_le(s, g_encryption ? 0x3 : 0); /* encryptionMethods */
out_uint32(s, 0); /* extEncryptionMethods */
+ /* Channel definitions (TS_UD_CS_NET) */
logger(Protocol, Debug, "sec_out_mcs_data(), g_num_channels is %d", g_num_channels);
if (g_num_channels > 0)
{
- out_uint16_le(s, SEC_TAG_CLI_CHANNELS);
+ out_uint16_le(s, CS_NET); /* type */
out_uint16_le(s, g_num_channels * 12 + 8); /* length */
out_uint32_le(s, g_num_channels); /* number of virtual channels */
for (i = 0; i < g_num_channels; i++)